@@ -1,22 +1,22 @@
 def handler(doc):
     from bottle import static_file, request
 
-    @doc.app.get(doc.uri())
-    @doc.app.get(doc.uri(r'/'))
+    @doc.app.get(doc.root_uri_absolute(slashes=True))
+    @doc.app.get(doc.root_uri_absolute(slashes=False))
     def index():
         return doc.doc_html
 
-    @doc.app.get(doc.uri(r'/swagger.json'))
+    @doc.app.get(doc.swagger_json_uri_absolute)
     def config_handler():
         return doc.get_config(request.urlparts.netloc)
 
-    @doc.app.get(doc.uri(r'/<filepath>'))
+    @doc.app.get(r'{}/<filepath>'.format(doc.static_uri_absolute))
     def java_script_file(filepath):
         return static_file(filepath, root=doc.static_dir)
 
     if doc.editor:
-        @doc.app.get(doc.uri(r'/editor'))
-        @doc.app.get(doc.uri(r'/editor/'))
+        @doc.app.get(doc.editor_uri_absolute(slashes=True))
+        @doc.app.get(doc.editor_uri_absolute(slashes=False))
         def editor():
             return doc.editor_html
 
